Games that can be played in the R console. Includes coin flip, hangman, jumble, magic 8 ball, poker, rock paper scissors, shut the box, spelling bee, and 2048.
Maintainer: Alexander Rossell Hayes [email protected] (ORCID) [copyright holder]
Other contributors:
Alan Beale [email protected] (Word lists) [data contributor]
Kevin Atkinson [email protected] (Word lists) [data contributor]
Luis Von Ahn (Word lists) [data contributor]
Flavia Rossell Hayes [illustrator]
Kristin Bott [email protected] (look_busy() status messages) [contributor]
Daniel Chen [email protected] (ORCID) (look_busy() status messages) [contributor]
Steven Smallberg [email protected] (look_busy() status messages) [contributor]
Useful links: